package Catmandu::MODS;
use strict;
use warnings;

our $VERSION = "0.2";

1;
__END__

=head1 NAME

Catmandu::MODS - Catmandu modules for working with MODS records

=head1 MODULES

=over

=item

L<Catmandu::Importer::MODS>

=back

=head1 CONTRIBUTORS

=over

=item Nicolas Franck

=item Jakob Voss

=back

=head1 COPYRIGHT

Copyright 2013- Nicolas Franck

=head1 LICENSE

This library is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=head1 SEE ALSO

L<MODS::Record>, L<Catmandu::XML>

MODS is specified and described at the Library of Congress:
L<http://www.loc.gov/standards/mods/>

=cut
